---
title: 웹훅 재 발송 기능
category: 결제서비스 (채널설정 및 이용안내) > 결제유형 > 정기결제
seo:
  description: 웹훅 재발송 기능을 설명하고 설정할 수 있는 방법에 대한 가이드입니다.
tags:
  - 공통
pgCompanies:
  - null
searchTags:
  - 웹훅
  - 웹훅발송
  - 웹훅재발송
datetime: 2024-04-18T10:00:41.772Z
---

<Callout icon="" title="웹훅 관련 정보" content="웹훅은 최초 또는 재발송 통해 전송이 가능하며, 각각 타임아웃이 다릅니다.
1.  최초 웹훅의 경우 &quot;Connection TimeOut 설정시각은 10초&quot;이며 가맹접 웹훅응답을 기다리는 &quot;Read TimeOut 시각은 30초&quot;입니다.
2.  재발송 웹훅의 경우 &quot;요청에 대한 전체 타임아웃이 15초&quot; 입니다." />

#### **1.** **자동** **재발송기능** **설정**

포트원의 웹훅은 1회 발송을 기본으로 하나, 고객사의 일시적인 오류 등으로 인하여 오류코드 응답시 1분단위로 최대 5회까지 재 전송되도록 설정이 가능합니다. \
아래 옵션 중 설정을 원하시는 경우를 선택하여 포트원 고객지원팀(<cs@portone.io>)으로 포트원 계정 주소와 함께 웹훅 재발송 기능적용을 요청 주시기 바랍니다.

\[설정옵션]

- 응답코드 : 0 혹은 500번대 일 때 발송

<Callout icon="💡" title="참고사항" content="**웹훅 응답코드가 0번, 500번대 인 경우**
웹훅 로그상 포트원→고객사로 정상적인 통지는 이루어졌으나, 응답 코드가 0번대 혹은 500번대로 오류가 발생된다면, 운영하시는 수신 서버(고객사 서버)에서 요청된 파라메터 데이터가 올바르지 않다고 판단하여 오류로 응답한 것입니다.
오류로 응답하신 사유는 포트원에서 파악하기 어려우며, 내부적으로 로그를 확인해주셔야 확인이 가능합니다 😊" />

#### **2.** **수기** **재발송** **기능**

• [포트원 관리자콘솔](https://admin.portone.io/) > 결제내역 > 결제내역 상세 > 웹훅 재발송 >웹훅 관리 클릭!

• 웹훅 로그에서 "웹훅 재발송처리" 도 가능 !



